Exception: Ipregistry::ParseError
- Inherits:
-
ClientError
- Object
- StandardError
- Error
- ClientError
- Ipregistry::ParseError
- Defined in:
- lib/ipregistry/errors.rb
Overview
Raised when a response body cannot be decoded as JSON.
Raised when a response body cannot be decoded as JSON.